pub fn render_output(output: &[OutputLine]) -> Vec<Line<'static>>Expand description
Converts the output buffer into a list of styled ratatui lines ready to render.
pub fn render_output(output: &[OutputLine]) -> Vec<Line<'static>>Converts the output buffer into a list of styled ratatui lines ready to render.